<?php

namespace Ecommerce\Controllers;

use Zeedhi\Framework\DTO;
use Zeedhi\Framework\DTO\Response\Error;

class Lib04500 extends \Zeedhi\Framework\Controller\Report
{

    protected $reportService;
    protected $autorizacaoFornecimentoController;
    protected $entityManager;
    
    public function __construct($reportService, $autorizacaoFornecimentoController, $entityManager)
    {
        $this->reportService = $reportService;
        $this->autorizacaoFornecimentoController = $autorizacaoFornecimentoController;
        $this->entityManager = $entityManager;
    }
    
    /** @var array */
    protected $reportMapping = array(
        'LIB04500' =>
            array(
                'strategy' => 'QR2',
                'parameterMapping' =>
                    array(
                        'TIPO'            => 'P_TIPO',
                        'CDFORNECED'      => 'P_CDFORNECED',
                        'CDFILLANC'       => 'P_CDFILLANC',
                        'NRSEQENVIOAFORN' => 'P_NRSEQENVIOAFORN',
                        'CDFILDEST'       => 'L_CDFILDEST',
                        'NRAUTOFORN'      => 'L_NRAUTOFORN',
                        'NRSEQAPURAF'     => 'L_NRSEQAPURAF'
                    )
            ),
        'LIB04501' =>
            array(
                'strategy' => 'QR2',
                'parameterMapping' =>
                    array(
                        'TIPO'            => 'P_TIPO',
                        'CDFORNECED'      => 'P_CDFORNECED',
                        'CDFILLANC'       => 'P_CDFILLANC',
                        'NRSEQENVIOAFORN' => 'P_NRSEQENVIOAFORN',
                        'CDFILDEST'       => 'L_CDFILDEST',
                        'NRAUTOFORN'      => 'L_NRAUTOFORN',
                        'NRSEQAPURAF'     => 'L_NRSEQAPURAF'
                    )
            ),
        'LIB04510' =>
            array(
                'strategy' => 'QR2',
                'parameterMapping' =>
                    array(
                        'CDFORNECED'      => 'P_CDFORNECED',
                        'CDFILLANC'       => 'P_CDFILLANC',
                        'CODOPERADOR'     => 'P_CODOPERADOR',
                        'CDFILDEST'       => 'L_CDFILDEST',
                        'NRAUTOFORN'      => 'L_NRAUTOFORN',
                        'NRSEQAPURAF'     => 'L_NRSEQAPURAF',
                        'NRSEQENVIOAFORN' => 'P_NRSEQENVIOAFORN'
                    )
            ),
        'LIB04502' =>
            array(
                'strategy' => 'BIRT',
                'parameterMapping' =>
                    array(
                        'CDFORNECED'      => 'P_CDFORNECED',
                        'CDFILLANC'       => 'P_CDFILLANC',
                        'CDFILDEST'       => 'L_CDFILDEST',
                        'NRAUTOFORN'      => 'L_NRAUTOFORN',
                        'NRSEQAPURAF'     => 'L_NRSEQAPURAF',
                        'NRSEQENVIOAFORN' => 'P_NRSEQENVIOAFORN',
                        'NRLOGPLANITEMAF' => 'P_NRLOGPLANITEMAF',
                        'CDPICTPROD'      => 'P_CDPICTPROD', 
                        "NRORG"           => 'NRORG'
                    )
            ),
        'padraoEnvioAF' => 
            array (
                'strategy' => 'BIRT',
                'parameterMapping' => 
                    array (
                        'CDFILDEST'      => 'P_CDFILIAL',
                        'NRAUTOFORN'     => 'P_NRAUTOFORN',
                        'CDFILLANCPADAF' => 'P_CDFILLANC',
                        'IDEXIBEOBSFIL'  => 'P_IDEXIBEOBSFIL',
                        'IMPRIMEOBSPROD' => 'P_IMPRIMEOBSPROD',
                        "NRORG"          => 'NRORG',
                    ),
            ),
        'padraoEnvioAFGR' => 
            array (
                'strategy' => 'BIRT',
                'parameterMapping' => 
                    array (
                        'CDFILDEST'      => 'P_CDFILIAL',
                        'NRAUTOFORN'     => 'P_NRAUTOFORN',
                        'CDFILLANCPADAF' => 'P_CDFILLANC',
                        'IDEXIBEOBSFIL'  => 'P_IDEXIBEOBSFIL',
                        'IMPRIMEOBSPROD' => 'P_IMPRIMEOBSPROD',
                        "NRORG"          => 'NRORG',
                    ),
            ),  
        'AFcomDescricaoProd' => 
            array (
                'strategy' => 'BIRT',
                'parameterMapping' => 
                    array (
                        'CDFILDEST'      => 'P_CDFILIAL',
                        'NRAUTOFORN'     => 'P_NRAUTOFORN',
                        'CDFILLANCPADAF' => 'P_CDFILLANC',
                        'IDEXIBEOBSFIL'  => 'P_IDEXIBEOBSFIL',
                        'IMPRIMEOBSPROD' => 'P_IMPRIMEOBSPROD',
                        "NRORG"          => 'NRORG',
                    ),
            )
    );
    
    public function afterProcessReport(DTO\Request\Row $request, DTO\Response $response, $report)
    {
        $row = $request->getRow();
        try {
            $this->entityManager->beginTransaction();
            
            $this->autorizacaoFornecimentoController->processaAfsBaixadas($row);
            
            $this->entityManager->commit();
        } catch (\Exception $e) {
            $this->entityManager->rollback();
            $response->setError(new Error($e->getMessage(), 1));
        }
        
    }
}