function AdministradorController(General, templateManager, ScreenService, MessageService) {
    /* global Constants */
    var senhaAlterada;
    var self = this;
    
    this.verificaPermissoes = function(widget) {
        const filtro = [ 
            { "name": "CDFORNECED", "operator": "=", "value": getLocalVar("CDFORNECED") },
            { "name": "DSLOGINECO", "operator": "=", "value": getLocalVar("EMAIL") }
        ];
        
        General.callRestEngine("product#/crud/dadosfornecommerce", "FilterData", filtro).then(function(success) {
            const permissoes = success.dataset.dadosfornecommerce[0];
            
            if (permissoes.IDACESSOAF == "S") {
                widget.getField("IDACESSOAF").readOnly = false;
            } else {
                widget.getField("IDACESSOAF").readOnly = true;
            }
                
            if (permissoes.IDACESSOCOT == "S") {
                widget.getField("IDACESSOCOT").readOnly = false;
            } else {
                widget.getField("IDACESSOCOT").readOnly = true;
            }
            
            if (permissoes.IDACESSOCR == "S") {
                widget.getField("IDACESSOCR").readOnly = false;
            } else {
                widget.getField("IDACESSOCR").readOnly = true;
            }
            
            if (permissoes.IDACESSOUPLOAD == "S") {
                widget.getField("IDACESSOUPLOAD").readOnly = false;
            } else {
                widget.getField("IDACESSOUPLOAD").readOnly = true;
            }
            
        }, function(err) {
            ScreenService.showMessage(err.data.error);
        });
    };
    
    this.verificaEmailLogin = function(widget) {
        if (widget.currentRow.DSLOGINECO == getLocalVar("EMAIL")) {
            widget.getAction("editar").isVisible  = false;
            widget.getAction("excluir").isVisible = false;
        } else {
            widget.getAction("editar").isVisible  = true;
            widget.getAction("excluir").isVisible = true;
        }
    };
    
    this.setNmUsuarioFieldEditable = function(widget) {
        const field = widget.getField("NMUSUARIOECO");
        
        if (field.value() != '' && field.value() != null) {
            field.readOnlyOnEdit = true;
        } else {
            field.readOnlyOnEdit = false;
        }
    };
    
    this.editar = function(widget) {
        widget.getField("CDSENHAWEB").class = 8;
        widget.getField("EDITARSENHA").isVisible = true;
        widget.getField("CDSENHAWEB").readOnlyOnEdit = true;
        
        this.setNmUsuarioFieldEditable(widget);
        this.verificaCopiaPara();
        
        senhaAlterada = 0;
        General.widgetEdit(widget);
    };
    
    this.cancelar = function(args) {
        args.owner.widget.getField("CDSENHAWEB").class = 12;
        args.owner.widget.getField("EDITARSENHA").isVisible = false;
        General.backOrCancel(args);
    };
    
    this.adicionar = function(widget) {
        widget.getField("EDITARSENHA").isVisible = false;
        widget.getField("CDSENHAWEB").class = 12;
        
        this.verificaCopiaPara();
        
        senhaAlterada = 1;
        General.widgetNewRow(widget);
    };
    
    this.excluir = function(widget) {
        widget.currentRow.MOTIVO_EMAIL = "exclusao";
        widget.currentRow.PORTAL = corrigeURL(window.location.href);
        widget.currentRow.OPERLOGADO = this.getNmUsuario();
        
        MessageService.confirmMessageByCode("deleteRegister").then(() => {
            General.callRestEngine("product#/excluirAcesso", "Row", widget.currentRow).then(function() {
                General.callRestEngine("product#/enviarEmail", "Row", widget.currentRow).then(undefined, function(err) {
                    ScreenService.errorNotification(err.data ? err.data.error : 'Houve uma falha ao encaminhar e-mail.');
                });
                
                ScreenService.closeSwipe();
                widget.reload();
                MessageService.notificationMessageByCode("successOnDelete", null, Constants.successNotification);
            }, function(err) {
                ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
            });
        });
    };
    
    this.salvar = function(widget, args) {
        if (widget.isValid()) {
            if (!this.validaEmail(widget.currentRow.DSLOGINECO)) {
                MessageService.showMessageByCode("invalidLogin", null, Constants.alertMessage);
                return false;
            }
            
            const emails = widget.currentRow.DSEMAILECO ? widget.currentRow.DSEMAILECO.split(";") : [];
            
            for (let i = 0; i < emails.length; i++) {
                if (!this.validaEmail(emails[i]) && emails[0] !== "") {
                    MessageService.showMessageByCode("invalidEmail", null, Constants.alertMessage);
                    return false;
                }
            }
            
            if (!widget.currentRow.CDFORNECED) {
                widget.currentRow.CDFORNECED = getLocalVar("CDFORNECED");
            }
            
            General.callRestEngine("product#/validacoesAcesso", "Row", widget.currentRow).then(function(success) {
                if (success.dataset.fornecedoresRelacionados.length > 0 && senhaAlterada == 1) {
                    widget.widgets[0].dataSource.data = success.dataset.fornecedoresRelacionados;
                    ScreenService.openPopup(widget.widgets[0]);
                    MessageService.showMessageByCode("loginRelated", null, Constants.alertMessage);
                } else {
                    salvarLogin();
                }
            }, function(err) {
                ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
            });
        }
    };
    
    this.continuarLoginRelacionado = function() {
        MessageService.confirmMessageByCode("confirmPasswordChange").then(() => {
            const rowWidget = templateManager.container.getWidget('acessoPortal').currentRow;
            
            ScreenService.closePopup();
            salvarLogin();
            
            General.callRestEngine("product#/salvarLoginRelacionado", "Row", rowWidget).then(function() {}, function(err) {
                ScreenService.showMessage(err.data.error);
            });
        }, function() {
            ScreenService.closePopup();
        });
    };
    
    this.getNmUsuario = function () {
        const localName = getLocalVar("NMUSUARIOECO");
        
        if (localName != '' && localName != null) {
            return localName;
        }
        
        return getLocalVar('EMAIL');
    };
    
    var salvarLogin = function() {
        var widget = templateManager.container.getWidget("acessoPortal");
        widget.currentRow.PORTAL = corrigeURL(window.location.href);
        widget.currentRow.OPERLOGADO = self.getNmUsuario();
        
        if (widget.currentRow.__is_new) {
            widget.currentRow.MOTIVO_EMAIL = "adicao";
            
            General.callRestEngine("product#/salvarNovoLogin", "Row", widget.currentRow).then(function() {
                General.callRestEngine("product#/enviarEmail", "Row", widget.currentRow).then(undefined, function(err) {
                    ScreenService.errorNotification(err.data ? err.data.error : 'Houve uma falha ao encaminhar e-mail.');
                });
                
                widget.getField("EDITARSENHA").isVisible = false;
                widget.getField("CDSENHAWEB").class = 12;
                widget.reload();
                widget.view();
                MessageService.notificationMessageByCode("successOnAccessAdd", null, Constants.successNotification);
            }, function(err) {
                ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
            });
        } else {
            var motivos = ["edicao"];
            if(widget.currentRow.IDACESSOAF != widget.backupRow.IDACESSOAF  || widget.currentRow.IDACESSOCOT != widget.backupRow.IDACESSOCOT || widget.currentRow.IDACESSOCR  != widget.backupRow.IDACESSOCR)
               motivos.push("permissao");
            if(senhaAlterada == 1) {
                widget.currentRow.SENHA_ALTERADA = "S";
                motivos.push("senha");
            } else {
                widget.currentRow.SENHA_ALTERADA = "N";
            }
            widget.currentRow.MOTIVO_EMAIL = motivos.join("_");
            
            General.callRestEngine("product#/salvarEdicaoLogin", "Row", widget.currentRow).then(function(success) {
                if (widget.currentRow.MOTIVO_EMAIL != 'edicao') {
                    General.callRestEngine("product#/enviarEmail", "Row", widget.currentRow).then(undefined, function(err) {
                        ScreenService.errorNotification(err.data ? err.data.error : 'Houve uma falha ao encaminhar e-mail.');
                    });
                }
            
                widget.getField("EDITARSENHA").isVisible = false;
                widget.getField("CDSENHAWEB").class = 12;
                widget.reload();
                widget.view();
                MessageService.notificationMessageByCode("successOnAccessEdit", null, Constants.successNotification);
            }, function(err) {
                ScreenService.showMessage(err.data ? err.data.error : 'Timeout', 'error');
            });
        }
    };
    
    this.editarSenha = function(widget) {
        senhaAlterada = 1;
        widget.getField("CDSENHAWEB").value("");
        widget.getField("CDSENHAWEB").readOnlyOnEdit = false;
    };
    
    this.validaEmail = function(email){
        var re = /^(([^<>()\[\]\\.,;:\s@"]+(\.[^<>()\[\]\\.,;:\s@"]+)*)|(".+"))@((\[[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}\.[0-9]{1,3}])|(([a-zA-Z\-0-9]+\.)+[a-zA-Z]{2,}))$/;
        if(!re.test(email)){
            return false;
        }
        return true;
	};
	
	var corrigeURL = function(url) {
        var index = url.indexOf('://');
        
        if (index > -1) {
            url = url.substr( index + 3 );
        }
        
        url = url.split("/")[0];
        return url;
	};
	
	this.verificaCopiaPara = function() {
        const widget = templateManager.container.getWidget("acessoPortal");
        
        if (widget.currentRow.IDACESSOCOT === 'N' && widget.currentRow.IDACESSOAF === 'N') {
            widget.getField("DSEMAILECO").readOnly = true;
            widget.currentRow.DSEMAILECO = "";
        } else {
            widget.getField("DSEMAILECO").readOnly = false;
        }
	};
    
    this.atualizaCurrentRow = function(widget) {
        if (widget.mode == ViewMode.VIEW) {
            var loginToFind = widget.currentRow.DSLOGINECO;
            widget.currentRow = widget.dataSource.data.filter(function(acesso){
                if (acesso.DSLOGINECO === loginToFind) {
                    return acesso;
                }
            })[0];
        }
    };
    
    this.voltar = function(widget) {
        ScreenService.closeSwipe();
        widget.list();
    };
}

Configuration(function(ContextRegister) {
	ContextRegister.register('AdministradorController', AdministradorController);
});